@@ -331,6 +331,10 @@ def __external_mod(cur_module, module, attrs):
         except ImportError:
             sys.stderr.write('ERROR: Python module %s not found\n' % module)
             return False
+        except ValueError: # weird ctypes case with wintypes
+            return False 
+        except RuntimeError: # When Gdk can't be initialized
+            return False
     except ValueError: # weird ctypes case with wintypes
         return False 
     except RuntimeError: # When Gdk can't be initialized
@@ -365,10 +369,14 @@ def __add_imports(imports, file, attrs):
         for node in ast.walk(tree):
             if isinstance(node, ast.Import):
                 for alias in node.names:
-                    if __external_mod(cur_module, alias.name, attrs):
+                    if alias.name and __external_mod(cur_module, alias.name, attrs):
                         imports.add(alias.name)
             if isinstance(node, ast.ImportFrom):
-                if __external_mod(cur_module, node.module, attrs):
+                if node.module == 'gi.repository':
+                    for name in node.names:
+                        imports.add('gi.repository.%s' % name.name)
+
+                elif node.module and __external_mod(cur_module, node.module, attrs):
                     imports.add(node.module)
     except SyntaxError as e:
         sys.stderr.write('WARNING: syntax errors in %s: %s\n' % (file, str(e)))
@@ -391,6 +399,9 @@ def __filter_namespace(modules):
     result = set()
 
     for m in modules:
+        if m.startswith('gi.repository.'):
+            result.add(m)
+            continue
         for p in _module_parents(m):
             if p in modules:
                 break
